package
Version:
v0.3.2
Opens a new window with list of versions in this module.
Published: Sep 29, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Input struct {
CInt *int64 `db:"c_int" json:"c_int,omitempty"`
CText *string `db:"c_text" json:"c_text,omitempty"`
}
type Model struct {
Id int64 `db:"id" json:"id,omitempty"`
Iduu uuid.UUID `db:"id_uu" json:"id_uu,omitempty"`
EntryAt lystype.Datetime `db:"entry_at" json:"entry_at,omitempty"`
Input
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.