lysexcel

package
v0.3.54 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: MIT Imports: 10 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WriteItems added in v0.3.26

func WriteItems[T any](items []T, jsonTagTypeMap map[string]reflect.Type, sheetName string, w io.Writer) (err error)

WriteItems writes an Excel workbook to a writer from items. T must have json tags set. Only the fields with a json tag get written. jsonTagTypeMap is a map of [json tag]type. sheetName is optional and defaults to "data".

func WriteItemsToFile

func WriteItemsToFile[T any](items []T, jsonTagTypeMap map[string]reflect.Type, sheetName, filePath string) (err error)

WriteItemsToFile creates an Excel workbook from items. T must have json tags set. Only the fields with a json tag get written. jsonTagTypeMap is a map of [json tag]type. sheetName is optional and defaults to "data".

Types

This section is empty.

Jump to