lysmap

package
v0.3.54 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FromRecs

func FromRecs[T any](recs []T) (recsMap []map[string]any, err error)

FromRecs converts a slice of recs (structs from db) to map[string]any using reflection. It only includes fields with a json tag and uses the json tag name as the map key. Embedded structs with no json tag are flattened recursively. Values are written with their native Go types.

Types

This section is empty.

Jump to