lysos

package
v0.3.56 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ValidateDir

func ValidateDir(dirPath, errPrefix string) error

ValidateDir checks if the provided directory path exists and is a directory. errPrefix is used in error messages to indicate the context of the validation (e.g. "Destination").

Types

This section is empty.

Jump to