Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WriteItems ¶ added in v0.3.26
func WriteItems[T any](items []T, jsonTagTypeMap map[string]reflect.Type, sheetName string, w io.Writer) (err error)
WriteItems writes an Excel workbook to a writer from items. T must have json tags set. Only the fields with a json tag get written. jsonTagTypeMap is a map of [json tag]type. sheetName is optional and defaults to "data".
func WriteItemsToFile ¶
func WriteItemsToFile[T any](items []T, jsonTagTypeMap map[string]reflect.Type, sheetName, filePath string) (err error)
WriteItemsToFile creates an Excel workbook from items. T must have json tags set. Only the fields with a json tag get written. jsonTagTypeMap is a map of [json tag]type. sheetName is optional and defaults to "data".
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.