Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ValidateDir ¶
ValidateDir checks if the provided directory path exists and is a directory. errPrefix is used in error messages to indicate the context of the validation (e.g. "Destination").
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.